package com.ruoyi.business.service;

import com.baomidou.mybatisplus.extension.service.IService;
import java.util.List;
import com.ruoyi.business.domain.TCusCustomer;

/**
 * 【请填写功能名称】Service接口
 * 
 * @author wms
 * @date 2022-06-12
 */
public interface ITCusCustomerService extends IService<TCusCustomer>
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param customerId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public TCusCustomer selectTCusCustomerByCustomerId(String customerId);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tCusCustomer 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TCusCustomer> selectTCusCustomerList(TCusCustomer tCusCustomer);

    /**
     * 新增【请填写功能名称】
     * 
     * @param tCusCustomer 【请填写功能名称】
     * @return 结果
     */
    public int insertTCusCustomer(TCusCustomer tCusCustomer);

    /**
     * 修改【请填写功能名称】
     * 
     * @param tCusCustomer 【请填写功能名称】
     * @return 结果
     */
    public int updateTCusCustomer(TCusCustomer tCusCustomer);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param customerIds 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteTCusCustomerByCustomerIds(String customerIds);

    /**
     * 删除【请填写功能名称】信息
     * 
     * @param customerId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteTCusCustomerByCustomerId(String customerId);
}
